==> gambas2_1.9.49.orig.tar.gz: gambas2-1.9.49/gb.gtk/src/CWindow.h <==
/***************************************************************************

  CWindow.h

  (c) 2004-2006 - Daniel Campos Fernández <dcamposf@gmail.com>
  
  GTK+ component
  
  Realizado para la Junta de Extremadura. 
  Consejería de Educación Ciencia y Tecnología. 
  Proyecto gnuLinEx
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 1, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

***************************************************************************/

#ifndef __CWINDOW_H
#define __CWINDOW_H


#include "gambas.h"
#include "main.h"
#include "widgets.h"
#include "CWidget.h"
#include "CPicture.h"

#ifndef __CWINDOW_CPP

extern GB_DESC CWindowMenusDesc[];
extern GB_DESC CWindowDesc[];
extern GB_DESC CWindowsDesc[];
extern GB_DESC CFormDesc[];

#else

#define THIS ((CWINDOW *)_object)
#define WINDOW ((gMainWindow*)(THIS->widget))
#define CWINDOW_PROPERTIES CWIDGET_PROPERTIES \
  ",Text,Icon,Picture,Mask,Persistent,Border,Minimized,Maximized,FullScreen,TopOnly,SkipTaskbar,Arrangement,Spacing,Padding"
  
#endif

typedef  struct
{
	GB_BASE ob;
	gControl *widget;
	GB_VARIANT_VALUE tag;
	

	CPICTURE *icon;
	CPICTURE *picture;
	unsigned persistent : 1;
	unsigned modal : 1;
	unsigned embed : 1;

}  CWINDOW;

typedef  struct 
{
    CWINDOW window;

}  CFORM;


#endif

CWINDOW* WINDOW_get_main();
void WINDOW_kill(CWINDOW *win);

==> gambas2_2.0.0.orig.tar.gz: gambas2-2.0.0/gb.gtk/src/CWindow.h <==
/***************************************************************************

  CWindow.h

  (c) 2004-2006 - Daniel Campos Fernández <dcamposf@gmail.com>
  
  GTK+ component
  
  Realizado para la Junta de Extremadura. 
  Consejería de Educación Ciencia y Tecnología. 
  Proyecto gnuLinEx
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 1, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

***************************************************************************/

#ifndef __CWINDOW_H
#define __CWINDOW_H

#include "main.h"
#include "gmainwindow.h"
#include "CWidget.h"
#include "CPicture.h"

typedef  
	struct
	{
		GB_BASE ob;
		gControl *widget;
		GB_VARIANT_VALUE tag;
		int ret;
		unsigned embed : 1;
	}  
	CWINDOW;

typedef
	CWINDOW CFORM;

#ifndef __CWINDOW_CPP

extern GB_DESC CWindowMenusDesc[];
extern GB_DESC CWindowControlsDesc[];
extern GB_DESC CWindowDesc[];
extern GB_DESC CWindowsDesc[];
extern GB_DESC CFormDesc[];

extern CWINDOW *CWINDOW_Active;

#else

#define THIS ((CWINDOW *)_object)
#define WINDOW ((gMainWindow*)(THIS->widget))
  
#endif

CWINDOW* WINDOW_get_main();
void WINDOW_kill(CWINDOW *win);

#endif
